@@ -55,7 +55,7 @@ static int load_booleans(const sepol_bool_t * boolean,
 	return 0;
 }
 
-static int check_booleans(struct avc_t *avc, struct boolean_t **bools)
+static int check_booleans(struct boolean_t **bools)
 {
 	char errormsg[PATH_MAX];
 	struct sepol_av_decision avd;
@@ -376,7 +376,7 @@ static PyObject *analyze(PyObject *self __attribute__((unused)) , PyObject *args
 		avc->tsid = tsid;
 		avc->tclass = tclass;
 		avc->av = av;
-		if (check_booleans(avc, &bools) == 0) {
+		if (check_booleans(&bools) == 0) {
 			if (av & ~avd.auditdeny) {
 				RETURN(DONTAUDIT)
 			} else {
@@ -390,15 +390,15 @@ static PyObject *analyze(PyObject *self __attribute__((unused)) , PyObject *args
 				len++; b++;
 			}
 			b = bools;
-			PyObject *boollist = PyTuple_New(len);
+			PyObject *outboollist = PyTuple_New(len);
 			len=0;
 			while(b->name) {
 				PyObject *bool = Py_BuildValue("(si)", b->name, b->active);
-				PyTuple_SetItem(boollist, len++, bool);
+				PyTuple_SetItem(outboollist, len++, bool);
 				b++;
 			}
 			free(bools);
-			PyTuple_SetItem(result, 1, boollist);
+			PyTuple_SetItem(result, 1, outboollist);
 			return result;
 		}
 	}
